==> edxia-0.1.10.tar.gz: edxia-0.1.10/edxia/utils/coordinates.py <==
# Copyright (c) 2019 Fabien Georget <fabien.georget@epfl.ch>, EPFL
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors
# may be used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

"""Util function to manage coordinates"""

import numpy as np
from skimage.measure import regionprops

def rc_to_xy(arr2d, r, c):
    """Returns the xy coordinates

    :param arr2d: an numpy array
    :param r: row coordinate
    :param c: column coordinates
    :returns: (x,y) coordinates
    """
    return (c, arr2d.shape[0]-1-r)

def xy_to_rc(arr2d, x, y):
    """Returns the rc coordinates

    :param arr2d: an numpy array
    :param r: row coordinate
    :param c: column coordinates
    :returns: (x,y) coordinates
    """
    return (arr2d.shape[0]-1-y, x)

def get_center_areas(labels):
    """Return the coordinates of the center of each areas in the segmented image"""
    pts = [r.centroid for r in regionprops(labels+1)]
    rcpts = np.asarray(pts, dtype=np.int)
    return rcpts

def get_values_at(coordinates, arr):
    """Return the values of 'arr' at 'coordinates'"""
    return arr[coordinates[:,0],coordinates[:,1]]

==> edxia-0.1.14.tar.gz: edxia-0.1.14/edxia/utils/coordinates.py <==
# Copyright (c) 2019 Fabien Georget <fabien.georget@epfl.ch>, EPFL
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors
# may be used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

"""Util function to manage coordinates"""

import numpy as np
from skimage.measure import regionprops

def rc_to_xy(arr2d, r, c):
    """Returns the xy coordinates

    :param arr2d: an numpy array
    :param r: row coordinate
    :param c: column coordinates
    :returns: (x,y) coordinates
    """
    return (c, arr2d.shape[0]-1-r)

def xy_to_rc(arr2d, x, y):
    """Returns the rc coordinates

    :param arr2d: an numpy array
    :param r: row coordinate
    :param c: column coordinates
    :returns: (x,y) coordinates
    """
    return (arr2d.shape[0]-1-y, x)

def get_center_areas(labels):
    """Return the coordinates of the center of each areas in the segmented image"""
    pts = [r.centroid for r in regionprops(labels+1)]
    rcpts = np.asarray(pts, dtype=int)
    return rcpts

def get_values_at(coordinates, arr):
    """Return the values of 'arr' at 'coordinates'"""
    return arr[coordinates[:,0],coordinates[:,1]]
